# Generated by Django 5.0.9 on 2024-10-29 09:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sop_infra', '0004_sopinfra_master_site'),
    ]

    operations = [
        migrations.AddField(
            model_name='sopinfra',
            name='site_user_count',
            field=models.CharField(blank=True, null=True),
        ),
    ]
